#
# Autogenerated by Thrift Compiler (0.7.0)
#
# DO NOT EDIT UNLESS YOU ARE SURE THAT YOU KNOW WHAT YOU ARE DOING
#
package Net::Evernote::Simple::EDAMUserStore::Constants;
require 5.6.0;
use strict;
use warnings;
use Thrift;


use constant EDAM_VERSION_MAJOR => 1;

use constant EDAM_VERSION_MINOR => 21;

1;
