#
# Autogenerated by Thrift Compiler (0.7.0)
#
# DO NOT EDIT UNLESS YOU ARE SURE THAT YOU KNOW WHAT YOU ARE DOING
#
package Net::Evernote::Simple::EDAMTypes::Constants;
require 5.6.0;
use strict;
use warnings;
use Thrift;


use constant EDAM_NOTE_SOURCE_WEB_CLIP => "web.clip";

use constant EDAM_NOTE_SOURCE_MAIL_CLIP => "mail.clip";

use constant EDAM_NOTE_SOURCE_MAIL_SMTP_GATEWAY => "mail.smtp";

1;
